@@ -31,6 +31,7 @@
 typedef enum /*< flags,prefix=GPLUGIN_CORE_FLAGS,underscore_name=GPLUGIN_CORE >*/ {
 	GPLUGIN_CORE_FLAGS_NONE = 0,
 	GPLUGIN_CORE_FLAGS_DISABLE_NATIVE_LOADER = 1 << 0,
+	GPLUGIN_CORE_FLAGS_LOG_PLUGIN_STATE_CHANGES = 1 << 1,
 } GPluginCoreFlags;
 /* clang-format on */
 
@@ -39,6 +40,8 @@ G_BEGIN_DECLS
 void gplugin_init(GPluginCoreFlags flags);
 void gplugin_uninit(void);
 
+GPluginCoreFlags gplugin_get_flags(void);
+
 G_END_DECLS
 
 #endif /* GPLUGIN_CORE_H */
