@@ -53,10 +53,92 @@
  * #GPluginLoaderClass defines the behavior for loading plugins.
  */
 
+typedef struct {
+	gchar *id;
+} GPluginLoaderPrivate;
+
+enum {
+	PROP_0,
+	PROP_ID,
+	N_PROPERTIES,
+};
+static GParamSpec *properties[N_PROPERTIES] = {
+	NULL,
+};
+
+G_DEFINE_ABSTRACT_TYPE_WITH_PRIVATE(
+	GPluginLoader,
+	gplugin_loader,
+	G_TYPE_OBJECT);
+
+/******************************************************************************
+ * Helpers
+ *****************************************************************************/
+static void
+gplugin_loader_set_id(GPluginLoader *loader, const gchar *id)
+{
+	GPluginLoaderPrivate *priv = gplugin_loader_get_instance_private(loader);
+
+	g_free(priv->id);
+	priv->id = g_strdup(id);
+
+	g_object_notify_by_pspec(G_OBJECT(loader), properties[PROP_ID]);
+}
+
 /******************************************************************************
  * GObject Implementation
  *****************************************************************************/
-G_DEFINE_ABSTRACT_TYPE(GPluginLoader, gplugin_loader, G_TYPE_OBJECT);
+static void
+gplugin_loader_get_property(
+	GObject *obj,
+	guint param_id,
+	GValue *value,
+	GParamSpec *pspec)
+{
+	GPluginLoader *loader = GPLUGIN_LOADER(obj);
+
+	switch(param_id) {
+		case PROP_ID:
+			g_value_set_string(value, gplugin_loader_get_id(loader));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
+			break;
+	}
+}
+
+static void
+gplugin_loader_set_property(
+	GObject *obj,
+	guint param_id,
+	const GValue *value,
+	GParamSpec *pspec)
+{
+	GPluginLoader *loader = GPLUGIN_LOADER(obj);
+
+	switch(param_id) {
+		case PROP_ID:
+			gplugin_loader_set_id(loader, g_value_get_string(value));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID(obj, param_id, pspec);
+			break;
+	}
+}
+
+static void
+gplugin_loader_finalize(GObject *obj)
+{
+	GPluginLoader *loader = NULL;
+	GPluginLoaderPrivate *priv = NULL;
+
+	loader = GPLUGIN_LOADER(obj);
+	priv = gplugin_loader_get_instance_private(loader);
+
+	g_clear_pointer(&priv->id, g_free);
+
+	G_OBJECT_CLASS(gplugin_loader_parent_class)->finalize(obj);
+}
 
 static void
 gplugin_loader_init(G_GNUC_UNUSED GPluginLoader *loader)
@@ -66,12 +148,55 @@ gplugin_loader_init(G_GNUC_UNUSED GPluginLoader *loader)
 static void
 gplugin_loader_class_init(G_GNUC_UNUSED GPluginLoaderClass *klass)
 {
+	GObjectClass *obj_class = G_OBJECT_CLASS(klass);
+
+	obj_class->get_property = gplugin_loader_get_property;
+	obj_class->set_property = gplugin_loader_set_property;
+	obj_class->finalize = gplugin_loader_finalize;
+
+	/**
+	 * GPluginLoader::id:
+	 *
+	 * The identifier of the loader.
+	 *
+	 * Since: 0.34.0
+	 */
+	properties[PROP_ID] = g_param_spec_string(
+		"id",
+		"id",
+		"The identifier of the loader",
+		NULL,
+		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+
+	g_object_class_install_properties(obj_class, N_PROPERTIES, properties);
 }
 
 /******************************************************************************
  * API
  *****************************************************************************/
 
+/**
+ * gplugin_loader_get_id:
+ * @loader: The #GPluginLoader instance.
+ *
+ * Gets the identifier of @loader.
+ *
+ * Returns: The ID of @loader.
+ *
+ * Since: 0.34.0
+ */
+const gchar *
+gplugin_loader_get_id(GPluginLoader *loader)
+{
+	GPluginLoaderPrivate *priv = NULL;
+
+	g_return_val_if_fail(GPLUGIN_IS_LOADER(loader), NULL);
+
+	priv = gplugin_loader_get_instance_private(loader);
+
+	return priv->id;
+}
+
 /**
  * gplugin_loader_query_plugin:
  * @loader: The #GPluginLoader instance performing the query.
