@@ -145,8 +145,10 @@ gplugin_plugin_info_set_provides(
 }
 
 static void
-gplugin_plugin_info_set_priority(GPluginPluginInfo *info, gint priority) {
-	GPluginPluginInfoPrivate *priv = gplugin_plugin_info_get_instance_private(info);
+gplugin_plugin_info_set_priority(GPluginPluginInfo *info, gint priority)
+{
+	GPluginPluginInfoPrivate *priv =
+		gplugin_plugin_info_get_instance_private(info);
 
 	if(priority != priv->priority) {
 		priv->priority = priority;
@@ -593,8 +595,13 @@ gplugin_plugin_info_class_init(GPluginPluginInfoClass *klass)
 	 * Since: 0.32.0
 	 */
 	properties[PROP_PRIORITY] = g_param_spec_int(
-		"priority", "priority", "The priority of the plugin", G_MININT, G_MAXINT, 0,
-G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
+		"priority",
+		"priority",
+		"The priority of the plugin",
+		G_MININT,
+		G_MAXINT,
+		0,
+		G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS);
 
 	/**
 	 * GPluginPluginInfo:abi-version:
@@ -938,7 +945,8 @@ gplugin_plugin_info_get_provides(GPluginPluginInfo *info)
  * Since: 0.32.0
  */
 gint
-gplugin_plugin_info_get_priority(GPluginPluginInfo *info) {
+gplugin_plugin_info_get_priority(GPluginPluginInfo *info)
+{
 	GPluginPluginInfoPrivate *priv = NULL;
 
 	g_return_val_if_fail(GPLUGIN_IS_PLUGIN_INFO(info), 0);
