@@ -34,9 +34,17 @@ function gplugin_query()
 end
 
 function gplugin_load(plugin)
+	if plugin == nil then
+		error('plugin is nil')
+	end
+
 	return true
 end
 
 function gplugin_unload(plugin)
+	if plugin == nil then
+		error('plugin is nil')
+	end
+
 	return true
 end
