@@ -374,3 +374,14 @@ gplugin_perl_loader_register(GTypeModule *module)
 {
 	gplugin_perl_loader_register_type(module);
 }
+
+GPluginLoader *
+gplugin_perl_loader_new(void)
+{
+	/* clang-format off */
+	return GPLUGIN_LOADER(g_object_new(
+		GPLUGIN_PERL_TYPE_LOADER,
+		"id", "gplugin-perl5",
+		NULL));
+	/* clang-format on */
+}
