@@ -17,19 +17,20 @@ use strict;
 
 use Glib::Object::Introspection;
 
-Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0", package=> "GPlugin");
+Glib::Object::Introspection->setup(basename => "GPlugin", version => "1.0",
+                                   package => "GPlugin");
 
-sub gplugin_query() {
+sub gplugin_query {
 	return GPlugin::PluginInfo->new(
 		id => "gplugin/perl5-dependent-plugin",
 		dependencies => ['dependency1', 'dependency2'],
 	);
 }
 
-sub gplugin_load() {
+sub gplugin_load {
 	return 1;
 }
 
-sub gplugin_unload() {
+sub gplugin_unload {
 	return 1;
 }
