@@ -405,3 +405,14 @@ gplugin_python3_loader_register(GTypeModule *module)
 
 	gplugin_python3_loader_init_python();
 }
+
+GPluginLoader *
+gplugin_python3_loader_new(void)
+{
+	/* clang-format off */
+	return GPLUGIN_LOADER(g_object_new(
+		GPLUGIN_PYTHON3_TYPE_LOADER,
+		"id", "gplugin-python3",
+		NULL));
+	/* clang-format on */
+}
