@@ -36,8 +36,15 @@ def gplugin_query():
 
 
 def gplugin_load(plugin):
+    if not isinstance(plugin, GPlugin.Plugin):
+        raise Exception('plugin is not a GPlugin.Plugin')
+
     return True
 
 
 def gplugin_unload(plugin):
+    if not isinstance(plugin, GPlugin.Plugin):
+        raise Exception('plugin is not a GPlugin.Plugin')
+
     return True
+
